pub struct ElementBase {
pub id: i64,
pub version: i32,
pub timestamp: Option<DateTime<Utc>>,
pub user: Option<OsmUser>,
pub changeset_id: i64,
pub visible: bool,
pub tags: Vec<Tag>,
}Expand description
Common metadata shared by Node, Way and Relation.
See the module docs for the default values (visible = true,
version = changeset_id = -1, timestamp/user = None).
Fields
id: i64version: i32timestamp: Option<DateTime<Utc>>user: Option<OsmUser>changeset_id: i64visible: boolImplementations
Sourceimpl ElementBase
impl ElementBase
Creates base metadata for an element with only an id and tags (no version, timestamp or user information).