pub struct WayNode {
pub id: i64,
pub latitude: Option<i64>,
pub longitude: Option<i64>,
}Expand description
A reference to a node within a Way, optionally carrying the node’s coordinates.
Coordinates are in integer nanodegrees and are only populated when the PBF file
carries node locations on ways (LocationsOnWays optional feature).
Fields
id: i64The referenced node’s id.
latitude: Option<i64>longitude: Option<i64>Implementations